@@ -1,4 +1,4 @@
-Qanova <- function(formula, data, q = 0.5, nboot = 600){
+Qanova <- function(formula, data, q = 0.5, nboot = 600, ...){
   #
   # Test global hypothesis that J independent groups
   # have equal medians.
@@ -14,12 +14,12 @@ Qanova <- function(formula, data, q = 0.5, nboot = 600){
     mf <- model.frame(formula, data)
   }
   cl <- match.call()
-  
-  x <- split(model.extract(mf, "response"), mf[,2])   
-  
+
+  x <- split(model.extract(mf, "response"), mf[,2])
+
   op=3
   MC <- FALSE
-  
+
   chkcar=NA
   for(j in 1:length(x))chkcar[j]=length(unique(x[[j]]))
   #if(min(chkcar<20)) warning("Cardinality of sample space is less than 20 for one more groups. Type I error might not be controlled!")
@@ -32,16 +32,16 @@ Qanova <- function(formula, data, q = 0.5, nboot = 600){
      psimat[i,] <- output$psihat
      pvals[i] <- output$p.value
   }
-  
+
   psidf <- as.data.frame(psimat)
   rownames(psidf) <- paste0("q = ",q)
   colnames(psidf) <- paste0("con", 1:nc)
-  
+
   pvalues <- as.data.frame(cbind(pvals, p.adjust(pvals, method = 'hochberg')))
   rownames(pvalues) <- paste0("q = ",q)
   colnames(pvalues) <- c("p-value", "p-adj")
-  
+
   result <- list(psihat = psidf, p.value = pvalues, contrasts = output$con, call = cl)
   class(result) <- "qanova"
   result
-}
\ No newline at end of file
+}
