@@ -1,22 +1,22 @@
-bwtrim <- function(formula, id, data, tr = 0.2){
-  
+bwtrim <- function(formula, id, data, tr = 0.2, ...){
+
   if (missing(data)) {
     mf <- model.frame(formula)
   } else {
     mf <- model.frame(formula, data)
   }
   cl <- match.call()
-  
+
   mf1 <- match.call()
   m <- match(c("formula", "data", "id"), names(mf1), 0L)
   mf1 <- mf1[c(1L, m)]
   mf1$drop.unused.levels <- TRUE
   mf1[[1L]] <- quote(stats::model.frame)
-  mf1 <- eval(mf1, parent.frame())  
-  
+  mf1 <- eval(mf1, parent.frame())
+
   random1 <- mf1[, "(id)"]
   depvar <- colnames(mf)[1]
- 
+
   ## check which one is the within subjects factor
   if (all(length(table(random1)) == table(mf[,3]))) {
     ranvar <- colnames(mf)[3]
@@ -25,17 +25,17 @@ bwtrim <- function(formula, id, data, tr = 0.2){
     ranvar <- colnames(mf)[2]
     fixvar <- colnames(mf)[3]
   }
-  
+
   K <- length(table(mf[, ranvar]))  ## number of repeated measurements
   J <- length(table(mf[, fixvar]))  ## number of levels
   p <- J*K
   grp <- 1:p
-    
+
   fixsplit <- split(mf[,depvar], mf[,fixvar])
   indsplit <- split(mf[,ranvar], mf[,fixvar])
   dattemp <- mapply(split, fixsplit, indsplit, SIMPLIFY = FALSE)
   data <- do.call(c, dattemp)
-  
+
   tmeans<-0
   h<-0
   v<-matrix(0,p,p)
@@ -69,12 +69,12 @@ bwtrim <- function(formula, id, data, tr = 0.2){
   # Do test for factor A by B interaction
   cmat<-kron(cj,ck)  # Contrast matrix for factor A by B
   Qab<-johansp(cmat,tmeans,v,h,J,K)
-  
-  result <- list(Qa=Qa$teststat, A.p.value=as.numeric(Qa$siglevel), A.df = Qa$df, Qb=Qb$teststat, B.p.value=as.numeric(Qb$siglevel), B.df = Qb$df, 
+
+  result <- list(Qa=Qa$teststat, A.p.value=as.numeric(Qa$siglevel), A.df = Qa$df, Qb=Qb$teststat, B.p.value=as.numeric(Qb$siglevel), B.df = Qb$df,
                  Qab=Qab$teststat, AB.p.value=as.numeric(Qab$siglevel), AB.df = Qab$df,
                  call = cl, varnames = c(depvar, fixvar, ranvar))
   class(result) <- c("bwtrim")
   result
 }
 
-tsplit <- bwtrim
\ No newline at end of file
+tsplit <- bwtrim
