@@ -1,4 +1,4 @@
-mestse<-function(x,bend=1.28){
+mestse<-function(x,bend=1.28,...){
 #
 #   Estimate the standard error of M-estimator using Huber's Psi
 #   using estimate of influence function
@@ -6,4 +6,4 @@ mestse<-function(x,bend=1.28){
 n<-length(x)
 mestse<-sqrt(sum((ifmest(x,bend,op=2)^2))/(n*(n-1)))
 mestse
-}
\ No newline at end of file
+}
