@@ -1,4 +1,4 @@
-pb2gen <- function(formula, data, est = "mom", nboot = 599){
+pb2gen <- function(formula, data, est = "mom", nboot = 599, ...){
 
   if (missing(data)) {
     mf <- model.frame(formula)
@@ -6,14 +6,14 @@ pb2gen <- function(formula, data, est = "mom", nboot = 599){
     mf <- model.frame(formula, data)
   }
   cl <- match.call()
-  
+
   xy <- split(model.extract(mf, "response"), mf[,2])
   faclevels <- names(xy)
   x <- xy[[1]]
   y <- xy[[2]]
-  est <- get(est)  
-  
-  alpha=.05  
+  est <- get(est)
+
+  alpha=.05
   pr=TRUE
   x<-x[!is.na(x)] # Remove any missing values in x
   y<-y[!is.na(y)] # Remove any missing values in y
@@ -30,9 +30,9 @@ pb2gen <- function(formula, data, est = "mom", nboot = 599){
   temp<-sum(bvec<0)/nboot+sum(bvec==0)/(2*nboot)
   sig.level<-2*(min(temp,1-temp))
   se<-var(bvec)
-  
+
   result <- list(test = est(x)-est(y), conf.int = c(bvec[low],bvec[up]), p.value = sig.level, call = cl)
   class(result) <- "pb2"
   result
-  
+
 }
