@@ -1,4 +1,4 @@
-trimse <- function(x, tr = 0.2, na.rm = FALSE){
+trimse <- function(x, tr = 0.2, na.rm = FALSE, ...){
 #
 #  Estimate the standard error of the gamma trimmed mean
 #  The default amount of trimming is tr=.2.
